<?php

namespace Litecms\Smily\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Smily\Http\Requests\PersonalRequest;
use Litecms\Smily\Interfaces\PersonalRepositoryInterface;
use Litecms\Smily\Models\Personal;

/**
 * Resource controller class for personal.
 */
class PersonalResourceController extends BaseController
{

    /**
     * Initialize personal resource controller.
     *
     * @param type PersonalRepositoryInterface $personal
     *
     * @return null
     */
    public function __construct(PersonalRepositoryInterface $personal)
    {
        parent::__construct();
        $this->repository = $personal;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Smily\Repositories\Criteria\PersonalResourceCriteria::class);
    }

    /**
     * Display a list of personal.
     *
     * @return Response
     */
    public function index(PersonalRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Smily\Repositories\Presenter\PersonalPresenter::class)
                ->$function();
        }

        $personals = $this->repository->paginate();

        return $this->response->title(trans('smily::personal.names'))
            ->view('smily::personal.index', true)
            ->data(compact('personals'))
            ->output();
    }

    /**
     * Display personal.
     *
     * @param Request $request
     * @param Model   $personal
     *
     * @return Response
     */
    public function show(PersonalRequest $request, Personal $personal)
    {

        if ($personal->exists) {
            $view = 'smily::personal.show';
        } else {
            $view = 'smily::personal.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('smily::personal.name'))
            ->data(compact('personal'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new personal.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PersonalRequest $request)
    {

        $personal = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('smily::personal.name')) 
            ->view('smily::personal.create', true) 
            ->data(compact('personal'))
            ->output();
    }

    /**
     * Create new personal.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PersonalRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $personal                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('smily::personal.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('smily/personal/' . $personal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/smily/personal'))
                ->redirect();
        }

    }

    /**
     * Show personal for editing.
     *
     * @param Request $request
     * @param Model   $personal
     *
     * @return Response
     */
    public function edit(PersonalRequest $request, Personal $personal)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('smily::personal.name'))
            ->view('smily::personal.edit', true)
            ->data(compact('personal'))
            ->output();
    }

    /**
     * Update the personal.
     *
     * @param Request $request
     * @param Model   $personal
     *
     * @return Response
     */
    public function update(PersonalRequest $request, Personal $personal)
    {
        try {
            $attributes = $request->all();

            $personal->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('smily::personal.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('smily/personal/' . $personal->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('smily/personal/' . $personal->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the personal.
     *
     * @param Model   $personal
     *
     * @return Response
     */
    public function destroy(PersonalRequest $request, Personal $personal)
    {
        try {

            $personal->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('smily::personal.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('smily/personal/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('smily/personal/' . $personal->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple personal.
     *
     * @param Model   $personal
     *
     * @return Response
     */
    public function delete(PersonalRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('smily::personal.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('smily/personal'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/smily/personal'))
                ->redirect();
        }

    }

    /**
     * Restore deleted personals.
     *
     * @param Model   $personal
     *
     * @return Response
     */
    public function restore(PersonalRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('smily::personal.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/smily/personal'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/smily/personal/'))
                ->redirect();
        }

    }

}
